# Ractor::Channel

Adds a `channel:` option to `Ractor#send` and `Ractor.receive`

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'ractor-channel'
```

## Usage

```ruby
require 'ractor-channel'

using Ractor::Channel

r = Ractor.new do
  puts Ractor.receive channel: :info   # Specific channel
  puts Ractor.receive                  # Default channel (nil)
  puts Ractor.receive channel: :*      # Any channel
end

r.send :read_last, channel: :other
r.send :read_second
r.send :read_first, channel: :info
r.take

# Prints "read_first, read_second, read_last"
```

Using refinements is recommended, but it can alternatively be setup globally:

```ruby
require 'ractor-channel'

Ractor.prepend Ractor::Channel
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/marcandre/ractor-channel. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [code of conduct](https://github.com/marcandre/ractor-channel/blob/master/CODE_OF_CONDUCT.md).


## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## Code of Conduct

Everyone interacting in the Ractor::Channel project's codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/marcandre/ractor-channel/blob/master/CODE_OF_CONDUCT.md).
